@@ -5,16 +5,19 @@ from typing import Any, Dict, Type, Union
 
 import graphene
 from django.apps import apps
+from django.core.exceptions import FieldDoesNotExist
 from django.db import models
 from django.template.loader import render_to_string
 from graphene_django.types import DjangoObjectType
 
 try:
     from wagtail.contrib.settings.models import BaseGenericSetting, BaseSiteSetting
+    from wagtail.fields import RichTextField
 except ImportError:
     # Wagtail < 4.0
     from wagtail.contrib.settings.models import BaseSetting as BaseGenericSetting
     from wagtail.contrib.settings.models import BaseSetting as BaseSiteSetting
+    from wagtail.core.fields import RichTextField
 
 
 try:
@@ -227,6 +230,24 @@ def model_resolver(field):
         if callable(cls_field):
             return cls_field(info, **kwargs)
 
+        # Expand HTML if the value's field is richtext
+        try:
+            if hasattr(instance._meta, "get_field"):
+                field_model = instance._meta.get_field(field.field_name)
+            else:
+                field_model = instance._meta.fields[field.field_name]
+        except FieldDoesNotExist:
+            return cls_field
+
+        else:
+            if (
+                type(field_model) is RichTextField
+                and grapple_settings.RICHTEXT_FORMAT == "html"
+            ):
+                return render_to_string(
+                    "wagtailcore/richtext.html", {"html": expand_db_html(cls_field)}
+                )
+
         # If none of those then just return field
         return cls_field
 
@@ -353,7 +374,10 @@ def get_field_value(instance, field_name: str):
     """
     if isinstance(instance, StructValue):
         return instance[field_name]
-    elif isinstance(instance.value, RichText):
+    elif (
+        isinstance(instance.value, RichText)
+        and grapple_settings.RICHTEXT_FORMAT == "html"
+    ):
         # Allow custom markup for RichText
         return render_to_string(
             "wagtailcore/richtext.html", {"html": expand_db_html(instance.value.source)}
